@@ -3,7 +3,7 @@ __all__ = ["Config", "SmartPortConfig", "RegisterAccess", "SIGENERGY_MODBUS_PROT
 
 from . import const
 from .config import Config
-from .device_config import RegisterAccess, SmartPortConfig
+from .modbus_config import RegisterAccess, SmartPortConfig
 from .version import SIGENERGY_MODBUS_PROTOCOL, SIGENERGY_MODBUS_PROTOCOL_PUBLISHED
 from pathlib import Path
 import argparse
@@ -23,11 +23,32 @@ else:
 _logger = logging.getLogger("root")
 _logger.info(f"Release {Config.origin['sw']}")
 
+for _storage_base_path in ["/data/", "/var/lib/", str(Path.home()), "/tmp/"]:
+    if os.path.isdir(_storage_base_path) and os.access(_storage_base_path, os.W_OK):
+        path = Path(_storage_base_path, "sigenergy2mqtt")
+        Config.persistent_state_path = path.resolve()
+        if not path.is_dir():
+            _logger.info(f"Persistent state folder '{Config.persistent_state_path}' created")
+            path.mkdir()
+        else:
+            _logger.info(f"Persistent state folder '{Config.persistent_state_path}' already exists")
+        break
+if Config.persistent_state_path == ".":
+    _logger.critical("Unable to create persistent state folder!")
+    sys.exit(1)
+persistent_state_path = Path(Config.persistent_state_path)
+threshold_time = time.time() - (7 * 86400)
+for file in persistent_state_path.iterdir():
+    if file.is_file() and not file.name.endswith(".yaml") and not file.name.endswith(".publishable") and not file.name.endswith(".token") and file.stat().st_mtime < threshold_time:
+        _logger.info(f"Removing stale state file: {file} (last modified: {time.ctime(file.stat().st_mtime)})")
+        file.unlink()
+
 # region Arguments
 _parser = argparse.ArgumentParser(
     description="Reads the Sigenergy modbus interface and publishes the data to MQTT. The data will be published to MQTT in the Home Assistant MQTT Discovery format.",
-    epilog="Command line options over-ride values in the configuration file.",
+    epilog="Command line options over-ride values in the configuration file and environment variables.",
 )
+# region General Configuration
 _parser.add_argument(
     "-c",
     "--config",
@@ -62,6 +83,14 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW, None),
     help="The default value in kW used for sanity checks to validate the maximum and minimum values for actual value of power sensors and the delta value of energy sensors. The default value is 100 kW per second, and readings outside the range are ignored.",
 )
+_parser.add_argument(
+    "--no-metrics",
+    action="store_true",
+    dest=const.SIGENERGY2MQTT_NO_METRICS,
+    help="Do not publish any sigenergy2mqtt metrics.",
+)
+# endregion
+# region Home Assistant Configuration
 _parser.add_argument(
     "--hass-enabled",
     action="store_true",
@@ -106,13 +135,14 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_HASS_DEVICE_NAME_PREFIX, None),
     help="The prefix to use for Home Assistant entity names. Example: A prefix of 'prefix' will prepend 'prefix ' to names (default: '')",
 )
-
 _parser.add_argument(
     "--hass-discovery-only",
     action="store_true",
     dest=const.SIGENERGY2MQTT_HASS_DISCOVERY_ONLY,
     help="Exit immediately after publishing discovery. Does not read values from the Modbus interface, except to probe for device configuration.",
 )
+# endregion
+# region MQTT Configuration
 _parser.add_argument(
     "-b",
     "--mqtt-broker",
@@ -129,13 +159,25 @@ _parser.add_argument(
     dest=const.SIGENERGY2MQTT_MQTT_PORT,
     type=int,
     default=os.getenv(const.SIGENERGY2MQTT_MQTT_PORT, None),
-    help="The listening port of the MQTT broker (default: 1883)",
+    help="The listening port of the MQTT broker (default is 1883, unless --mqtt-tls is specified, in which case the default is 8883)",
+)
+_parser.add_argument(
+    "--mqtt-tls",
+    action="store_true",
+    dest=const.SIGENERGY2MQTT_MQTT_TLS,
+    help="Enable secure communication to MQTT broker over TLS/SSL. If specified, the default MQTT port is 8883.",
+)
+_parser.add_argument(
+    "--mqtt-tls-insecure",
+    action="store_true",
+    dest=const.SIGENERGY2MQTT_MQTT_TLS_INSECURE,
+    help="Enables insecure communication over TLS. If your broker is using a self-signed certificate, you must specify this option. Ignored unless --mqtt-tls is also specified.",
 )
 _parser.add_argument(
     "--mqtt-anonymous",
     action="store_true",
     dest=const.SIGENERGY2MQTT_MQTT_ANONYMOUS,
-    help="Connect to MQTT anonymously (i.e. without username/password).",
+    help="Allow anonymous connection to MQTT broker (i.e. without username/password). If specified, the --mqtt-username and --mqtt-password options are ignored.",
 )
 _parser.add_argument(
     "-u",
@@ -163,6 +205,15 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_MQTT_LOG_LEVEL, None),
     help="Set the paho.mqtt log level. Valid values are: DEBUG, INFO, WARNING, ERROR or CRITICAL. Default is WARNING (warnings, errors and critical failures)",
 )
+# endregion
+# region Modbus Configuration
+_parser.add_argument(
+    "--modbus-auto-discovery",
+    action="store",
+    dest=const.SIGENERGY2MQTT_MODBUS_AUTO_DISCOVERY,
+    choices=["once", "force"],
+    help="Attempt to auto-discover Sigenergy Modbus hosts and device IDs. If 'once' is specified, auto-discovery will only occur if no existing auto-discovery results are found. If 'force', auto-discovery will overwrite any previously discovered Modbus hosts and device IDs. If not specified, auto-discovery is disabled.",
+)
 _parser.add_argument(
     "-m",
     "--modbus-host",
@@ -252,6 +303,8 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_MODBUS_LOG_LEVEL, None),
     help="Set the pymodbus log level. Valid values are: DEBUG, INFO, WARNING, ERROR or CRITICAL. Default is WARNING (warnings, errors and critical failures)",
 )
+# endregion
+# region Scan Interval Configuration
 _parser.add_argument(
     "--scan-interval-low",
     nargs="?",
@@ -288,6 +341,8 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME, None),
     help="The scan interval in seconds for Modbus registers that are to be scanned in near-real time. Default is 5 (seconds), and the minimum value is 1.",
 )
+# endregion
+# region SmartPort Configuration
 _parser.add_argument(
     "--smartport-enabled",
     action="store_true",
@@ -351,6 +406,8 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_SMARTPORT_MQTT_GAIN, None),
     help="The gain to be applied to the production data for the third-party device obtained from the MQTT topic. (e.g. 1000 if the data is in kW) Default is 1 (Watts).",
 )
+# endregion
+# region PVOutput Configuration
 _parser.add_argument(
     "--pvoutput-enabled",
     action="store_true",
@@ -375,9 +432,11 @@ _parser.add_argument(
 )
 _parser.add_argument(
     "--pvoutput-consumption",
-    action="store_true",
+    nargs="?",
+    action="store",
     dest=const.SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION,
-    help="Enable sending consumption status to PVOutput.",
+    const="true",
+    help="Enable to send consumption data to PVOutput. If specified without a value, or with a value of 'true' or 'consumption', consumption data will be sent. With a value of 'imported', the energy imported from the grid will be sent as consumption. If not specified, no consumption data is sent.",
 )
 _parser.add_argument(
     "--pvoutput-interval",
@@ -404,12 +463,7 @@ _parser.add_argument(
     default=os.getenv(const.SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL, None),
     help="Set the PVOutput log level. Valid values are: DEBUG, INFO, WARNING, ERROR or CRITICAL. Default is WARNING (warnings, errors and critical failures)",
 )
-_parser.add_argument(
-    "--no-metrics",
-    action="store_true",
-    dest=const.SIGENERGY2MQTT_NO_METRICS,
-    help="Do not publish any sigenergy2mqtt metrics.",
-)
+# endregion
 _parser.add_argument(
     "--clean",
     action="store_true",
@@ -466,6 +520,8 @@ for arg in vars(_args):
         or arg == const.SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS
         or arg == const.SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS
         or arg == const.SIGENERGY2MQTT_MQTT_ANONYMOUS
+        or arg == const.SIGENERGY2MQTT_MQTT_TLS
+        or arg == const.SIGENERGY2MQTT_MQTT_TLS_INSECURE
         or arg == const.SIGENERGY2MQTT_PVOUTPUT_ENABLED
         or arg == const.SIGENERGY2MQTT_SMARTPORT_ENABLED
         or arg == const.SIGENERGY2MQTT_NO_METRICS
@@ -505,22 +561,3 @@ try:
 except Exception as e:
     _logger.critical(f"Error processing configuration: {e}")
     sys.exit(1)
-
-for _storage_base_path in ["/data/", "/var/lib/", str(Path.home()), "/tmp/"]:
-    if os.path.isdir(_storage_base_path) and os.access(_storage_base_path, os.W_OK):
-        path = Path(_storage_base_path, "sigenergy2mqtt")
-        Config.persistent_state_path = path.resolve()
-        if not path.is_dir():
-            path.mkdir()
-        logging.debug(f"{Config.persistent_state_path=}")
-        break
-if Config.persistent_state_path == ".":
-    _logger.critical("Unable to create persistent state path!")
-    sys.exit(1)
-
-directory = Path(Config.persistent_state_path)
-threshold_time = time.time() - (7 * 86400)
-for file in directory.iterdir():
-    if file.is_file() and not file.name.endswith(".publishable") and not file.name.endswith(".token") and file.stat().st_mtime < threshold_time:
-        _logger.debug(f"Removing stale state file: {file}")
-        file.unlink()
