@@ -1,10 +1,12 @@
 from . import const
 from . import version
-from .device_config import DeviceConfig
+from .auto_discovery import scan as auto_discovery_scan
 from .home_assistant_config import HomeAssistantConfiguration
+from .modbus_config import DeviceConfig
 from .mqtt_config import MqttConfiguration
 from .pvoutput_config import PVOutputConfiguration
 from .validation import check_bool, check_host, check_float, check_int, check_int_list, check_log_level, check_port, check_string
+from pathlib import Path
 from ruamel.yaml import YAML
 from typing import List
 import logging
@@ -48,12 +50,6 @@ class Config:
 
     @staticmethod
     def reload() -> None:
-        if Config._source:
-            _yaml = YAML(typ="safe", pure=True)
-            with open(Config._source, "r") as f:
-                data = _yaml.load(f)
-            Config._configure(data)
-
         overrides = {
             "home-assistant": {},
             "mqtt": {},
@@ -61,6 +57,28 @@ class Config:
             "pvoutput": {},
             "sensor-overrides": {},
         }
+
+        if Config._source:
+            _yaml = YAML(typ="safe", pure=True)
+            with open(Config._source, "r") as f:
+                data = _yaml.load(f)
+            Config._configure(data)
+
+        auto_discovery = os.getenv(const.SIGENERGY2MQTT_MODBUS_AUTO_DISCOVERY)
+        auto_discovery_cache = Path(Config.persistent_state_path, "auto-discovery.yaml")
+        auto_discovered = None
+        if auto_discovery == "force" or (auto_discovery == "once" and not auto_discovery_cache.is_file()):
+            port = int(os.getenv(const.SIGENERGY2MQTT_MODBUS_PORT, "502"))
+            logging.info(f"Auto-discovery required, scanning for Sigenergy devices ({port=})...")
+            auto_discovered = auto_discovery_scan(port)
+            with open(auto_discovery_cache, "w") as f:
+                _yaml = YAML(typ="safe", pure=True)
+                _yaml.dump(auto_discovered, f)
+        elif auto_discovery == "once" and auto_discovery_cache.is_file():
+            logging.info("Auto-discovery already completed, using cached results.")
+            with open(auto_discovery_cache, "r") as f:
+                auto_discovered = YAML(typ="safe", pure=True).load(f)
+
         for key, value in os.environ.items():
             if key.startswith("SIGENERGY2MQTT_") and key != "SIGENERGY2MQTT_CONFIG" and value is not None and value != "None":
                 logging.debug(f"Found env/cli override: {key} = {'******' if 'PASSWORD' in key or 'API_KEY' in key else value}")
@@ -89,12 +107,17 @@ class Config:
                             overrides["home-assistant"]["unique-id-prefix"] = check_string(os.environ[key], key)
                         case const.SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS:
                             overrides["home-assistant"]["use-simplified-topics"] = check_bool(os.environ[key], key)
+                        case const.SIGENERGY2MQTT_MODBUS_AUTO_DISCOVERY:
+                            check_string(os.environ[key], key, "force", "once", allow_none=True, allow_empty=True)
                         case const.SIGENERGY2MQTT_MODBUS_HOST:
                             overrides["modbus"][0]["host"] = check_host(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_PORT:
                             overrides["modbus"][0]["port"] = check_port(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MODBUS_LOG_LEVEL:
                             overrides["modbus"][0]["log-level"] = check_log_level(os.environ[key], key)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["log-level"] = overrides["modbus"][0]["log-level"]
                         case const.SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE | const.SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID:
                             overrides["modbus"][0]["inverters"] = check_int_list([int(device_id) for device_id in os.environ[key].split(",")], key)
                         case const.SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE | const.SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID:
@@ -103,20 +126,44 @@ class Config:
                             overrides["modbus"][0]["dc-chargers"] = check_int_list([int(device_id) for device_id in os.environ[key].split(",")], key)
                         case const.SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS:
                             overrides["modbus"][0]["no-remote-ems"] = check_bool(os.environ[key], key)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["no-remote-ems"] = overrides["modbus"][0]["no-remote-ems"]
                         case const.SIGENERGY2MQTT_MODBUS_READ_ONLY:
                             overrides["modbus"][0]["read-only"] = check_bool(os.environ[key], key)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["read-only"] = overrides["modbus"][0]["read-only"]
                         case const.SIGENERGY2MQTT_MODBUS_READ_WRITE:
                             overrides["modbus"][0]["read-write"] = check_bool(os.environ[key], key)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["read-write"] = overrides["modbus"][0]["read-write"]
                         case const.SIGENERGY2MQTT_MODBUS_WRITE_ONLY:
                             overrides["modbus"][0]["write-only"] = check_bool(os.environ[key], key)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["write-only"] = overrides["modbus"][0]["write-only"]
                         case const.SIGENERGY2MQTT_SCAN_INTERVAL_LOW:
                             overrides["modbus"][0]["scan-interval-low"] = check_int(os.environ[key], key, min=300)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["scan-interval-low"] = overrides["modbus"][0]["scan-interval-low"]
                         case const.SIGENERGY2MQTT_SCAN_INTERVAL_MEDIUM:
                             overrides["modbus"][0]["scan-interval-medium"] = check_int(os.environ[key], key, min=30)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["scan-interval-medium"] = overrides["modbus"][0]["scan-interval-medium"]
                         case const.SIGENERGY2MQTT_SCAN_INTERVAL_HIGH:
                             overrides["modbus"][0]["scan-interval-high"] = check_int(os.environ[key], key, min=5)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["scan-interval-high"] = overrides["modbus"][0]["scan-interval-high"]
                         case const.SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME:
                             overrides["modbus"][0]["scan-interval-realtime"] = check_int(os.environ[key], key, min=1)
+                            if auto_discovered:
+                                for device in auto_discovered:
+                                    device["scan-interval-realtime"] = overrides["modbus"][0]["scan-interval-realtime"]
                         case const.SIGENERGY2MQTT_SMARTPORT_ENABLED:
                             overrides["modbus"][0]["smart-port"]["enabled"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_SMARTPORT_MODULE_NAME:
@@ -137,6 +184,10 @@ class Config:
                             overrides["mqtt"]["broker"] = check_host(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MQTT_PORT:
                             overrides["mqtt"]["port"] = check_port(os.environ[key], key)
+                        case const.SIGENERGY2MQTT_MQTT_TLS:
+                            overrides["mqtt"]["tls"] = check_bool(os.environ[key], key)
+                        case const.SIGENERGY2MQTT_MQTT_TLS_INSECURE:
+                            overrides["mqtt"]["tls-insecure"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MQTT_ANONYMOUS:
                             overrides["mqtt"]["anonymous"] = check_bool(os.environ[key], key)
                         case const.SIGENERGY2MQTT_MQTT_LOG_LEVEL:
@@ -154,13 +205,11 @@ class Config:
                         case const.SIGENERGY2MQTT_PVOUTPUT_SYSTEM_ID:
                             overrides["pvoutput"]["system-id"] = check_string(os.environ[key], key, allow_none=False, allow_empty=False)
                         case const.SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION:
-                            overrides["pvoutput"]["consumption"] = check_bool(os.environ[key], key)
+                            overrides["pvoutput"]["consumption"] = check_string(os.environ[key], key, "false", "true", "consumption", "imported", allow_empty=False, allow_none=False)
                         case const.SIGENERGY2MQTT_PVOUTPUT_INTERVAL:
                             pass  # Deprecated
                         case const.SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC:
                             overrides["pvoutput"]["temperature-topic"] = check_string(os.environ[key], key, allow_none=False, allow_empty=False)
-                        case const.SIGENERGY2MQTT_PVOUTPUT_TESTING:
-                            overrides["pvoutput"]["testing"] = check_bool(os.environ[key], key)
                         case _:
                             logging.warning(f"UNKNOWN env/cli override: {key} = {'******' if 'PASSWORD' in key or 'API_KEY' in key else value}")
                 except Exception as e:
@@ -168,8 +217,31 @@ class Config:
 
         Config._configure(overrides, True)
 
+        if auto_discovered:
+            if isinstance(auto_discovered, list):
+                for device in auto_discovered:
+                    updated = False
+                    for defined in Config.devices:
+                        if (defined.host == device.get("host") or defined.host == "") and defined.port == device.get("port"):
+                            if defined.host == "":
+                                defined.host = device.get("host")
+                                defined.port = device.get("port")
+                                logging.info(f"Auto-discovery found new Modbus device: {device.get('host')}:{device.get('port')}")
+                            else:
+                                logging.info(f"Auto-discovered found configured Modbus device: {device.get('host')}:{device.get('port')}, updating with discovered device IDs")
+                            defined.configure(device, override=True, auto_discovered=True)
+                            updated = True
+                            break
+                    if not updated:
+                        logging.info(f"Auto-discovery found new Modbus device: {device.get('host')}:{device.get('port')}")
+                        new_device = DeviceConfig()
+                        new_device.configure(device, override=True, auto_discovered=True)
+                        Config.devices.append(new_device)
+            else:
+                raise ValueError("Auto-discovery results must be a list of modbus device configurations")
+
         if len(Config.devices) == 0:
-            raise ValueError("No modbus devices found in configuration file.")
+            raise ValueError("No Modbus devices configured")
 
     @staticmethod
     def _configure(data: dict, override: bool = False) -> None:
