@@ -16,6 +16,7 @@ SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS: Final = "SIGENERGY2MQTT_HASS_USE_SIMP
 
 SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID: Final = "SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID"
 SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE"  # Deprecated, use SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID
+SIGENERGY2MQTT_MODBUS_AUTO_DISCOVERY: Final = "SIGENERGY2MQTT_MODBUS_AUTO_DISCOVERY"
 SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID: Final = "SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID"
 SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE"  # Deprecated, use SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID
 SIGENERGY2MQTT_MODBUS_HOST: Final = "SIGENERGY2MQTT_MODBUS_HOST"
@@ -33,6 +34,8 @@ SIGENERGY2MQTT_MQTT_BROKER: Final = "SIGENERGY2MQTT_MQTT_BROKER"
 SIGENERGY2MQTT_MQTT_LOG_LEVEL: Final = "SIGENERGY2MQTT_MQTT_LOG_LEVEL"
 SIGENERGY2MQTT_MQTT_PASSWORD: Final = "SIGENERGY2MQTT_MQTT_PASSWORD"
 SIGENERGY2MQTT_MQTT_PORT: Final = "SIGENERGY2MQTT_MQTT_PORT"
+SIGENERGY2MQTT_MQTT_TLS: Final = "SIGENERGY2MQTT_MQTT_TLS"
+SIGENERGY2MQTT_MQTT_TLS_INSECURE: Final = "SIGENERGY2MQTT_MQTT_TLS_INSECURE"
 SIGENERGY2MQTT_MQTT_USERNAME: Final = "SIGENERGY2MQTT_MQTT_USERNAME"
 
 SIGENERGY2MQTT_PVOUTPUT_API_KEY: Final = "SIGENERGY2MQTT_PVOUTPUT_API_KEY"
