@@ -19,11 +19,9 @@ class HomeAssistantConfiguration:
 
     def configure(self, config: dict, override: bool = False) -> None:
         if isinstance(config, dict):
-            for field, value in config.items():
-                match field:
-                    case "enabled":
-                        logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: home-assistant.{field} = {value}")
-                        self.enabled = check_bool(value, f"home-assistant.{field}")
+            if "enabled" in config:
+                logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: home-assistant.enabled = {config['enabled']}")
+                self.enabled = check_bool(config["enabled"], "home-assistant.enabled")
             if self.enabled:
                 for field, value in config.items():
                     if field != "enabled":
