@@ -7,7 +7,7 @@ import logging
 class PVOutputConfiguration:
     enabled: bool = False
 
-    consumption: bool = False
+    consumption: str | None = None
     exports: bool = False
     peak_power: bool = True
 
@@ -25,11 +25,9 @@ class PVOutputConfiguration:
 
     def configure(self, config: dict, override: bool = False) -> None:
         if isinstance(config, dict):
-            for field, value in config.items():
-                match field:
-                    case "enabled":
-                        logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: pvoutput.enabled = {value}")
-                        self.enabled = check_bool(value, f"pvoutput.{field}")
+            if "enabled" in config:
+                logging.debug(f"Applying {'override from env/cli' if override else 'configuration'}: pvoutput.enabled = {config['enabled']}")
+                self.enabled = check_bool(config['enabled'], "pvoutput.enabled")
             if self.enabled:
                 for field, value in config.items():
                     if field != "enabled":
@@ -38,7 +36,15 @@ class PVOutputConfiguration:
                         case "api-key":
                             self.api_key = check_string(value, "pvoutput.api-key", allow_none=(not self.enabled), allow_empty=(not self.enabled), hex_chars_only=True)
                         case "consumption":
-                            self.consumption = check_bool(value, f"pvoutput.{field}")
+                            match value:
+                                case False | "false":
+                                    self.consumption = None
+                                case True | "true" | "consumption":
+                                    self.consumption = "consumption"
+                                case "imported":
+                                    self.consumption = "imported"
+                                case _:
+                                    raise ValueError(f"pvoutput.consumption must be 'true', 'false', or 'imports', got '{value}'")
                         case "exports":
                             self.exports = check_bool(value, f"pvoutput.{field}")
                         case "interval-minutes":
