@@ -6,6 +6,7 @@ import asyncio
 import logging
 import os
 import paho.mqtt.client as mqtt
+import ssl
 import time
 
 logger = logging.getLogger("paho.mqtt")
@@ -142,11 +143,37 @@ def on_unsubscribe(client: mqtt.Client, userdata: MqttHandler, mid, reason_codes
 
 
 class MqttClient(mqtt.Client):
-    def __init__(self, client_id: str = "", clean_session: bool = None, userdata: MqttHandler = None, protocol: int = mqtt.MQTTv311, transport: str = "tcp", reconnect_on_failure: bool = True):
+    def __init__(
+        self,
+        client_id: str | None = "",
+        clean_session: bool | None = None,
+        userdata: MqttHandler = None,
+        protocol: int = mqtt.MQTTv311,
+        transport: str = "tcp",
+        reconnect_on_failure: bool = True,
+    ):
         super().__init__(
-            mqtt.CallbackAPIVersion.VERSION2, client_id=client_id, clean_session=clean_session, userdata=userdata, protocol=protocol, transport=transport, reconnect_on_failure=reconnect_on_failure
+            mqtt.CallbackAPIVersion.VERSION2,
+            client_id=client_id,
+            clean_session=clean_session,
+            userdata=userdata,
+            protocol=protocol,
+            transport=transport,
+            reconnect_on_failure=reconnect_on_failure,
         )
         self.enable_logger(logger)
+        if Config.mqtt.tls:
+            ssl_context = ssl.create_default_context()
+            if Config.mqtt.tls_insecure:
+                ssl_context.check_hostname = False
+                ssl_context.verify_mode = ssl.CERT_NONE
+                logging.warning(f"Using insecure TLS connection (not recommended) to MQTT broker {Config.mqtt.broker}:{Config.mqtt.port} as Client ID '{client_id}'")
+            else:
+                ssl_context.check_hostname = True
+                ssl_context.verify_mode = ssl.CERT_REQUIRED
+                logging.info(f"Using secure TLS connection to MQTT broker {Config.mqtt.broker}:{Config.mqtt.port} as Client ID '{client_id}'")
+            self.tls_set_context(ssl_context)
+            self.tls_insecure_set(Config.mqtt.tls_insecure)
 
         self.on_disconnect = on_disconnect
         self.on_connect = on_connect
