@@ -13,8 +13,10 @@ from typing import Any, Coroutine, Dict, Final
 import abc
 import asyncio
 import datetime
+import html
 import json
 import logging
+import re
 import sys
 import time
 
@@ -297,6 +299,22 @@ class Sensor(Dict[str, any], metaclass=abc.ABCMeta):
         self["availability"] = [{"topic": f"{Config.home_assistant.discovery_prefix}/device/{device_id}/availability"}]
         return base
 
+    def get_attributes(self) -> dict[str, Any]:
+        """Gets the Home Assistant attributes for this sensor.
+
+        Returns:
+            A dictionary of attributes for this sensor.
+        """
+        attributes = {}
+        attributes["sensor-class"] = self.__class__.__name__
+        if self._gain:
+            attributes["gain"] = self._gain
+        if hasattr(self, "_scan_interval"):
+            attributes["scan-interval"] = self._scan_interval
+        if hasattr(self, "command_topic"):
+            attributes["update-topic"] = self.command_topic
+        return attributes
+
     def get_discovery(self, mqtt: MqttClient) -> Dict[str, dict[str, Any]]:
         """Gets the Home Assistant MQTT auto-discovery components for this sensor.
 
@@ -418,13 +436,7 @@ class Sensor(Dict[str, any], metaclass=abc.ABCMeta):
             **kwargs:   key=value pairs that will be added as attributes.
         """
         if self.publishable and not Config.clean:
-            attributes = {}
-            attributes["sensor-class"] = self.__class__.__name__
-            attributes["gain"] = self._gain
-            if hasattr(self, "_scan_interval"):
-                attributes["scan-interval"] = self._scan_interval
-            if hasattr(self, "command_topic"):
-                attributes["update-topic"] = self.command_topic
+            attributes = {key: html.unescape(value) if isinstance(value, str) else value for key, value in self.get_attributes().items()}
             for k, v in kwargs.items():
                 attributes[k] = v
             if self._debug_logging:
@@ -737,8 +749,10 @@ class ReadOnlySensor(ModbusSensor, ReadableSensorMixin):
 
         return result
 
-    def publish_attributes(self, mqtt: MqttClient, **kwargs):
-        return super().publish_attributes(mqtt, source=self._address, **kwargs)
+    def get_attributes(self) -> dict[str, Any]:
+        attributes = super().get_attributes()
+        attributes["source"] = self._address
+        return attributes
 
 
 class ReservedSensor(ReadOnlySensor):
@@ -784,7 +798,7 @@ class ReservedSensor(ReadOnlySensor):
             precision,
             unique_id_override=unique_id_override,
         )
-        self.publishable = False  # Reserved sensors are not published
+        self._publishable = False  # Reserved sensors are not published
 
     @property
     def publishable(self) -> bool:
@@ -794,8 +808,6 @@ class ReservedSensor(ReadOnlySensor):
     def publishable(self, value: bool):
         if value:
             raise ValueError("Cannot set publishable=True for ReservedSensor")
-        else:
-            logging.debug(f"{self.__class__.__name__} Ignored request to set publishable to {value} (reserved sensor)")
 
     def apply_sensor_overrides(self, registers):
         pass
@@ -935,8 +947,12 @@ class WriteOnlySensor(WritableSensorMixin):
         plant_index: int,
         device_address: int,
         address: int,
-        icon_on: str = "mdi:power-on",
+        payload_off: str = "off",
+        payload_on: str = "on",
+        name_off: str = "Power Off",
+        name_on: str = "Power On",
         icon_off: str = "mdi:power-off",
+        icon_on: str = "mdi:power-on",
     ):
         super().__init__(
             name,
@@ -958,35 +974,38 @@ class WriteOnlySensor(WritableSensorMixin):
         assert icon_off is not None and icon_off.startswith("mdi:"), f"{self.__class__.__name__} off icon {icon_off} does not start with 'mdi:'"
         self["platform"] = "button"
         self["enabled_by_default"] = True
-        self._icons = {"Off": icon_off, "On": icon_on}
+        self._payloads = {"off": payload_off, "on": payload_on}
+        self._names = {"off": name_off, "on": name_on}
+        self._icons = {"off": icon_off, "on": icon_on}
 
     def get_discovery_components(self) -> Dict[str, dict[str, Any]]:
         components = {}
-        for action in ["On", "Off"]:
-            lower_action = action.lower()
+        for action in ["On", "Off"]:  # Remove legacy entities first
+            components[f"{self.unique_id}_{action}"] = {"p": "button"}
+        for action in ["on", "off"]:
             config = {}
             for k, v in self.items():
                 if v is not None:
                     if k == "name":
-                        config[k] = f"{v} {action}"
+                        config[k] = self._names[action]
                     elif k == "object_id" or k == "unique_id":
-                        config[k] = f"{v}_{lower_action}"
+                        config[k] = f"{v}_{self._payloads[action]}"
                     else:
                         config[k] = v
             config["icon"] = self._icons[action]
-            config["payload_press"] = action
+            config["payload_press"] = self._payloads[action]
             components[f"{self.unique_id}_{action}"] = config
         if self._debug_logging:
             logging.debug(f"{self.__class__.__name__} Discovered {components=}")
         return components
 
     async def set_value(self, modbus: ModbusClient, mqtt: MqttClient, value: float | int | str, source: str, handler: MqttHandler) -> bool:
-        if value == "Off":
+        if value == self._payloads["off"]:
             return await super().set_value(modbus, mqtt, 0, source, handler)
-        elif value == "On":
+        elif value == self._payloads["on"]:
             return await super().set_value(modbus, mqtt, 1, source, handler)
         else:
-            logging.warning(f"{self.__class__.__name__} Ignored attempt to set value to {value}: Must be either 'On' or 'Off'")
+            logging.warning(f"{self.__class__.__name__} Ignored attempt to set value to {value}: Must be either '{self._payloads['on']}' or '{self._payloads['off']}'")
         return False
 
 
@@ -1194,7 +1213,7 @@ class AlarmSensor(ReadOnlySensor, metaclass=abc.ABCMeta):
             address,
             count=1,
             data_type=ModbusClient.DATATYPE.UINT16,
-            scan_interval=Config.devices[plant_index].scan_interval.high if plant_index < len(Config.devices) else 10,
+            scan_interval=Config.devices[plant_index].scan_interval.realtime if plant_index < len(Config.devices) else 5,
             unit=None,
             device_class=None,
             state_class=None,
@@ -1251,7 +1270,14 @@ class AlarmSensor(ReadOnlySensor, metaclass=abc.ABCMeta):
             if not active_alarms:
                 return f"Unknown Alarm {value}"
             else:
-                return ", ".join(active_alarms)
+                alarms = ", ".join(active_alarms)
+                if Config.home_assistant.enabled:
+                    max_length = 255 if not ("max_length" in kwargs and isinstance(kwargs["max_length"], int) and int(kwargs["max_length"]) > 0) else int(kwargs["max_length"])
+                    if len(alarms) > max_length:
+                        alarms = re.sub(r"\s+", " ", re.sub(r"[0-9:_]", "", alarms)).strip()
+                        if len(alarms) > max_length:
+                            alarms = alarms[: (max_length - 3)] + "..."
+                return alarms
 
 
 class Alarm1Sensor(AlarmSensor):
@@ -1483,12 +1509,16 @@ class AlarmCombinedSensor(Sensor, ReadableSensorMixin, HybridInverter, PVInverte
         else:
             result = AlarmSensor.NO_ALARM
             for alarm in self._alarms:
-                state = await alarm.get_state(raw=False, republish=False, **kwargs)
+                state = await alarm.get_state(raw=False, republish=False, max_length=sys.maxsize, **kwargs)
                 if state != AlarmSensor.NO_ALARM:
                     if result == AlarmSensor.NO_ALARM:
                         result = state
                     else:
                         result = ", ".join([result, state])
+                        if len(result) > 255 and Config.home_assistant.enabled:
+                            result = re.sub(r"\s+", " ", re.sub(r"[0-9:_]", "", result)).strip()
+                            if len(result) > 255:
+                                result = result[:252] + "..."
             self.set_state(result)
             return self._apply_gain_and_precision(self._states[-1][1], raw)
 
@@ -1598,8 +1628,11 @@ class ResettableAccumulationSensor(DerivedSensor, ObservableMixin):
         topics.add(self._reset_topic)
         return topics
 
-    def publish_attributes(self, mqtt, **kwargs):
-        return super().publish_attributes(mqtt, reset_topic=self._reset_topic, reset_unit=self.unit)
+    def get_attributes(self) -> dict[str, Any]:
+        attributes = super().get_attributes()
+        attributes["reset_topic"] = self._reset_topic
+        attributes["reset_unit"] = self.unit
+        return attributes
 
 
 class EnergyLifetimeAccumulationSensor(ResettableAccumulationSensor):
@@ -1627,7 +1660,7 @@ class EnergyLifetimeAccumulationSensor(ResettableAccumulationSensor):
             with self._persistent_state_file.open("r") as f:
                 try:
                     content = f.read()
-                    if content is not None and content != "None" and content.isdecimal():
+                    if content is not None and content != "None":
                         self._current_total = float(content)
                         logging.info(f"{self.__class__.__name__} Loaded current state from {self._persistent_state_file} ({self._current_total})")
                 except ValueError as error:
@@ -1701,7 +1734,7 @@ class EnergyDailyAccumulationSensor(ResettableAccumulationSensor):
             name, unique_id, object_id, source, unit=source.unit, device_class=source.device_class, state_class=source["state_class"], icon=source["icon"], gain=source.gain, precision=source.precision
         )
         self._state_at_midnight_lock = asyncio.Lock()
-        self._state_at_midnight: float = source.latest_raw_state
+        self._state_at_midnight: float = None
         self._persistent_state_file = Path(Config.persistent_state_path, f"{source.unique_id}.atmidnight")
         if self._persistent_state_file.is_file():
             fmt = time.localtime(self._persistent_state_file.stat().st_mtime)
@@ -1710,7 +1743,7 @@ class EnergyDailyAccumulationSensor(ResettableAccumulationSensor):
                 with self._persistent_state_file.open("r") as f:
                     try:
                         content = f.read()
-                        if content is not None and content != "None" and content.isdecimal():
+                        if content is not None and content != "None":
                             value = float(content)
                             if value <= 0.0:
                                 logging.debug(f"{self.__class__.__name__} Ignored negative last midnight state from {self._persistent_state_file} ({value})")
@@ -1726,11 +1759,6 @@ class EnergyDailyAccumulationSensor(ResettableAccumulationSensor):
                 self._persistent_state_file.unlink(missing_ok=True)
         else:
             logging.debug(f"{self.__class__.__name__} Persistent state file {self._persistent_state_file} not found")
-        self._state_now: float = max(0.0, source.latest_raw_state - self._state_at_midnight) if source.latest_raw_state else 0.0
-        logging.debug(f"{self.__class__.__name__} Setting latest state = {self._state_now} (max(0.0, {source.latest_raw_state=} - {self._state_at_midnight=}))")
-        self.set_latest_state(self._state_now)
-        if not self._persistent_state_file.is_file():
-            self.futures.add(asyncio.run_coroutine_threadsafe(self._update_state_at_midnight(self._state_at_midnight), asyncio.get_running_loop()))
 
     async def notify(self, modbus: ModbusClient, mqtt: MqttClient, value: float | int | str, source: str, handler: MqttHandler) -> bool:
         if source in self.observable_topics():
@@ -1766,14 +1794,20 @@ class EnergyDailyAccumulationSensor(ResettableAccumulationSensor):
             if was.tm_year != now.tm_year or was.tm_mon != now.tm_mon or was.tm_mday != now.tm_mday:
                 asyncio.run_coroutine_threadsafe(self._update_state_at_midnight(now_state), asyncio.get_running_loop())
 
-        self._state_now = now_state - (self._state_at_midnight if self._state_at_midnight else now_state)
+        if not self._state_at_midnight:
+            self._state_at_midnight = now_state
+
+        self._state_now = now_state - self._state_at_midnight
         self.set_latest_state(self._state_now)
 
     async def _update_state_at_midnight(self, midnight_state: float) -> None:
-        async with self._state_at_midnight_lock:
-            with self._persistent_state_file.open("w") as f:
-                f.write(str(midnight_state))
-            self._state_at_midnight = midnight_state
+        if midnight_state:
+            async with self._state_at_midnight_lock:
+                with self._persistent_state_file.open("w") as f:
+                    f.write(str(midnight_state))
+                self._state_at_midnight = midnight_state
+        else:
+            logging.warning(f"{self.__class__.__name__} Ignored attempt to update midnight state to {midnight_state}")
 
 
 class PVPowerSensor:
