@@ -815,6 +815,11 @@ class InverterPCSAlarm(AlarmCombinedSensor):
             *alarms,
         )
 
+    def get_attributes(self) -> dict[str, Any]:
+        attributes = super().get_attributes()
+        attributes["source"] = "Modbus Registers 30605 and 30606"
+        return attributes
+
 
 class InverterAlarm3(Alarm3Sensor, HybridInverter):
     def __init__(self, plant_index: int, device_address: int):
@@ -1455,6 +1460,7 @@ class PVCurrentSensor(ReadOnlySensor, HybridInverter, PVInverter):
             gain=100,
             precision=2,
         )
+        self.string_number = string_number
 
 
 class PVVoltageSensor(ReadOnlySensor, HybridInverter, PVInverter):
@@ -1477,6 +1483,7 @@ class PVVoltageSensor(ReadOnlySensor, HybridInverter, PVInverter):
             gain=10,
             precision=1,
         )
+        self.string_number = string_number
 
 
 class InverterPVPower(ReadOnlySensor, HybridInverter, PVInverter):
@@ -1600,7 +1607,7 @@ class VehicleChargingCurrent(ReadOnlySensor, HybridInverter, PVInverter):
 class DCChargerOutputPower(ReadOnlySensor, HybridInverter, PVInverter):
     def __init__(self, plant_index: int, device_address: int):
         super().__init__(
-            name="DC Charger Output Power",
+            name="Output Power",
             object_id=f"{Config.home_assistant.entity_id_prefix}_{plant_index}_plant_dc_charger_output_power",
             input_type=InputType.INPUT,
             plant_index=plant_index,
@@ -1608,7 +1615,7 @@ class DCChargerOutputPower(ReadOnlySensor, HybridInverter, PVInverter):
             address=31502,
             count=2,
             data_type=ModbusClient.DATATYPE.INT32,
-            scan_interval=Config.devices[plant_index].scan_interval.high if plant_index < len(Config.devices) else 10,
+            scan_interval=Config.devices[plant_index].scan_interval.realtime if plant_index < len(Config.devices) else 5,
             unit=UnitOfPower.KILO_WATT,
             device_class=DeviceClass.POWER,
             state_class=None,
@@ -1642,7 +1649,7 @@ class VehicleSoC(ReadOnlySensor, HybridInverter, PVInverter):
 class DCChargerCurrentChargingCapacity(ReadOnlySensor, HybridInverter, PVInverter):
     def __init__(self, plant_index: int, device_address: int):
         super().__init__(
-            name="DC Charger Current Charging Capacity",
+            name="Current Charging Capacity",
             object_id=f"{Config.home_assistant.entity_id_prefix}_{plant_index}_plant_dc_charger_current_charging_capacity",
             input_type=InputType.INPUT,
             plant_index=plant_index,
@@ -1659,14 +1666,16 @@ class DCChargerCurrentChargingCapacity(ReadOnlySensor, HybridInverter, PVInverte
             precision=2,
         )
 
-    def publish_attributes(self, mqtt, **kwargs) -> None:
-        return super().publish_attributes(mqtt, comment="Single time", **kwargs)
+    def get_attributes(self) -> dict[str, Any]:
+        attributes = super().get_attributes()
+        attributes["comment"] = "Single time"
+        return attributes
 
 
 class DCChargerCurrentChargingDuration(ReadOnlySensor, HybridInverter, PVInverter):
     def __init__(self, plant_index: int, device_address: int):
         super().__init__(
-            name="DC Charger Current Charging Duration",
+            name="Current Charging Duration",
             object_id=f"{Config.home_assistant.entity_id_prefix}_{plant_index}_plant_dc_charger_current_charging_duration",
             input_type=InputType.INPUT,
             plant_index=plant_index,
@@ -1683,8 +1692,10 @@ class DCChargerCurrentChargingDuration(ReadOnlySensor, HybridInverter, PVInverte
             precision=None,
         )
 
-    def publish_attributes(self, mqtt, **kwargs) -> None:
-        return super().publish_attributes(mqtt, comment="Single time", **kwargs)
+    def get_attributes(self) -> dict[str, Any]:
+        attributes = super().get_attributes()
+        attributes["comment"] = "Single time"
+        return attributes
 
 
 # endregion
